@@ -3,6 +3,6 @@ histoPlot <- function(af, nbins = 50) {
        hist(af$ri, nclass = nbins, xlab = "", main = "FCROS statistics", xlim = c(0, 1));
     }
     else {
-       hist(af$u1, nclass = nbins, xlab = "", main = "PFCO statistics");
+       hist(af$u1, nclass = nbins, xlab = "", main = "PFCO statistics", xlim = c(0, 1));
     }
 }
